pub struct Arch;Trait Implementations
Sourceimpl ArchFunctionality for X64
impl ArchFunctionality for X64
Sourcefn perf_frequency() -> u64
fn perf_frequency() -> u64
Value in Hz of how often the counter increment.
Sourcefn cpu_count_start() -> u64
fn cpu_count_start() -> u64
Value the performance counter starts with when it rolls over.
Sourcefn cpu_count_end() -> u64
fn cpu_count_end() -> u64
Value that the performance counter ends with before it rolls over.