Instant

Struct Instant 

pub struct Instant { /* private fields */ }
This struct is used to calculate the duration between two instant.

Example

use perf_timer::Instant;

let start = Instant::now();

// ...

let duration = start.elapsed();

Implementations

Source

impl Instant

pub fn now() -> Self

Create a new instant.

pub fn from_cpu_count(cpu_count: u64) -> Self

Create a new instant from a cpu count.

pub fn beginning() -> Self

Create a new instant from the start of the counter.

pub fn duration_since(&self, earlier: &Self) -> Duration

Return the amount of time from earlier adn this instant.

Panic

This function will panic if earlier is not in the past.

pub fn elapsed(&self) -> Duration

Return the amount of time that elapsed since now and this instant.