pub struct Instant { /* private fields */ }Expand description
This struct is used to calculate the duration between two instant.
Example
use perf_timer::Instant;
let start = Instant::now();
// ...
let duration = start.elapsed();Implementations
Sourceimpl Instant
impl Instant
Sourcepub fn from_cpu_count(cpu_count: u64) -> Self
pub fn from_cpu_count(cpu_count: u64) -> Self
Create a new instant from a cpu count.
Sourcepub fn duration_since(&self, earlier: &Self) -> Duration
pub fn duration_since(&self, earlier: &Self) -> Duration
Return the amount of time from earlier adn this instant.
Panic
This function will panic if earlier is not in the past.