pub trait ArchFunctionality {
// Required methods
fn cpu_count() -> u64;
fn perf_frequency() -> u64;
// Provided methods
fn cpu_count_start() -> u64 { ... }
fn cpu_count_end() -> u64 { ... }
}Required Methods
Sourcefn perf_frequency() -> u64
fn perf_frequency() -> u64
Value in Hz of how often the counter increment.
Provided Methods
Sourcefn cpu_count_start() -> u64
fn cpu_count_start() -> u64
Value the performance counter starts with when it rolls over.
Sourcefn cpu_count_end() -> u64
fn cpu_count_end() -> u64
Value that the performance counter ends with before it rolls over.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.